@@ -3,7 +3,7 @@
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
@@ -15,15 +15,15 @@
 
 package org.kie.internal.task.api;
 
+import org.kie.api.runtime.Context;
 import org.kie.api.task.UserGroupCallback;
-import org.kie.internal.command.Context;
 
 public interface TaskContext extends Context, org.kie.api.task.TaskContext {
 
-	TaskPersistenceContext getPersistenceContext();
-	
-	void setPersistenceContext(TaskPersistenceContext context);
-	
-	UserGroupCallback getUserGroupCallback();
+    TaskPersistenceContext getPersistenceContext();
+
+    void setPersistenceContext(TaskPersistenceContext context);
+
+    UserGroupCallback getUserGroupCallback();
 
 }
